==> drools-quarkus-unit-example-0.3.0-sources.jar: org/kie/kogito/queries/RulesF894883E1030542FEFCE9860F835B9B7_AdultUnitRuleMethods0.java <==
package org.kie.kogito.queries;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import org.kie.kogito.queries.Person;
import static org.kie.kogito.queries.RulesF894883E1030542FEFCE9860F835B9B7.*;

public class RulesF894883E1030542FEFCE9860F835B9B7_AdultUnitRuleMethods0 {

    /**
     * Rule name: CheckAdult
     */
    public static org.drools.model.Rule rule_CheckAdult() {
        final org.drools.model.Variable<org.kie.kogito.queries.Person> var_$p = D.declarationOf(org.kie.kogito.queries.Person.class,
                                                                                                DomainClassesMetadataF894883E1030542FEFCE9860F835B9B7.org_kie_kogito_queries_Person_Metadata_INSTANCE,
                                                                                                "$p",
                                                                                                D.entryPoint("persons"));
        final org.drools.model.BitMask mask_$p = org.drools.model.BitMask.getPatternMask(DomainClassesMetadataF894883E1030542FEFCE9860F835B9B7.org_kie_kogito_queries_Person_Metadata_INSTANCE,
                                                                                         "adult");
        org.drools.model.Rule rule = D.rule("org.kie.kogito.queries",
                                            "CheckAdult").unit(org.kie.kogito.queries.AdultUnit.class)
                                                         .build(D.pattern(var_$p).expr("8A10059B61A05CC10AA4813D4D8E800B",
                                                                                       var_adultAge,
                                                                                       (_this, adultAge) -> org.drools.modelcompiler.util.EvaluationUtil.greaterOrEqualNumbers(_this.getAge(),
                                                                                                                                                                               adultAge),
                                                                                       D.betaIndexedBy(java.lang.Integer.class,
                                                                                                       org.drools.model.Index.ConstraintType.GREATER_OR_EQUAL,
                                                                                                       0,
                                                                                                       _this -> _this.getAge(),
                                                                                                       adultAge -> adultAge),
                                                                                       D.reactOn("age")),
                                                                D.on(var_$p).execute((drools, $p) -> {
                                                                    {
                                                                        ($p).setAdult(true);
                                                                        drools.update($p,
                                                                                      mask_$p);
                                                                    }
                                                                }));
        return rule;
    }

    /**
     * Rule name: CheckNotAdult
     */
    public static org.drools.model.Rule rule_CheckNotAdult() {
        final org.drools.model.Variable<org.kie.kogito.queries.Person> var_$p = D.declarationOf(org.kie.kogito.queries.Person.class,
                                                                                                DomainClassesMetadataF894883E1030542FEFCE9860F835B9B7.org_kie_kogito_queries_Person_Metadata_INSTANCE,
                                                                                                "$p",
                                                                                                D.entryPoint("persons"));
        final org.drools.model.BitMask mask_$p = org.drools.model.BitMask.getPatternMask(DomainClassesMetadataF894883E1030542FEFCE9860F835B9B7.org_kie_kogito_queries_Person_Metadata_INSTANCE,
                                                                                         "adult");
        org.drools.model.Rule rule = D.rule("org.kie.kogito.queries",
                                            "CheckNotAdult").unit(org.kie.kogito.queries.AdultUnit.class)
                                                            .build(D.pattern(var_$p).expr("1ECF1D07CB65DA08A27F2E9295AE2940",
                                                                                          var_adultAge,
                                                                                          (_this, adultAge) -> org.drools.modelcompiler.util.EvaluationUtil.lessThanNumbers(_this.getAge(),
                                                                                                                                                                            adultAge),
                                                                                          D.betaIndexedBy(java.lang.Integer.class,
                                                                                                          org.drools.model.Index.ConstraintType.LESS_THAN,
                                                                                                          0,
                                                                                                          _this -> _this.getAge(),
                                                                                                          adultAge -> adultAge),
                                                                                          D.reactOn("age")),
                                                                   D.on(var_$p).execute((drools, $p) -> {
                                                                       {
                                                                           ($p).setAdult(false);
                                                                           drools.update($p,
                                                                                         mask_$p);
                                                                       }
                                                                   }));
        return rule;
    }
}

==> drools-quarkus-unit-example-0.5.1-sources.jar: org/kie/kogito/queries/RulesF894883E1030542FEFCE9860F835B9B7_AdultUnitRuleMethods0.java <==
package org.kie.kogito.queries;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import org.kie.kogito.queries.Person;
import static org.kie.kogito.queries.RulesF894883E1030542FEFCE9860F835B9B7.*;

public class RulesF894883E1030542FEFCE9860F835B9B7_AdultUnitRuleMethods0 {

    /**
     * Rule name: CheckAdult
     */
    public static org.drools.model.Rule rule_CheckAdult() {
        final org.drools.model.Variable<org.kie.kogito.queries.Person> var_$p = D.declarationOf(org.kie.kogito.queries.Person.class,
                                                                                                DomainClassesMetadataF894883E1030542FEFCE9860F835B9B7.org_kie_kogito_queries_Person_Metadata_INSTANCE,
                                                                                                "$p",
                                                                                                D.entryPoint("persons"));
        final org.drools.model.BitMask mask_$p = org.drools.model.BitMask.getPatternMask(DomainClassesMetadataF894883E1030542FEFCE9860F835B9B7.org_kie_kogito_queries_Person_Metadata_INSTANCE,
                                                                                         "adult");
        org.drools.model.Rule rule = D.rule("org.kie.kogito.queries",
                                            "CheckAdult").unit(org.kie.kogito.queries.AdultUnit.class)
                                                         .build(D.pattern(var_$p).expr("8A10059B61A05CC10AA4813D4D8E800B",
                                                                                       var_adultAge,
                                                                                       (_this, adultAge) -> org.drools.modelcompiler.util.EvaluationUtil.greaterOrEqualNumbers(_this.getAge(),
                                                                                                                                                                               adultAge),
                                                                                       D.betaIndexedBy(java.lang.Integer.class,
                                                                                                       org.drools.model.Index.ConstraintType.GREATER_OR_EQUAL,
                                                                                                       DomainClassesMetadataF894883E1030542FEFCE9860F835B9B7.org_kie_kogito_queries_Person_Metadata_INSTANCE.getPropertyIndex("age"),
                                                                                                       _this -> _this.getAge(),
                                                                                                       adultAge -> adultAge),
                                                                                       D.reactOn("age")),
                                                                D.on(var_$p).execute((drools, $p) -> {
                                                                    {
                                                                        ($p).setAdult(true);
                                                                        drools.update($p,
                                                                                      mask_$p);
                                                                    }
                                                                }));
        return rule;
    }

    /**
     * Rule name: CheckNotAdult
     */
    public static org.drools.model.Rule rule_CheckNotAdult() {
        final org.drools.model.Variable<org.kie.kogito.queries.Person> var_$p = D.declarationOf(org.kie.kogito.queries.Person.class,
                                                                                                DomainClassesMetadataF894883E1030542FEFCE9860F835B9B7.org_kie_kogito_queries_Person_Metadata_INSTANCE,
                                                                                                "$p",
                                                                                                D.entryPoint("persons"));
        final org.drools.model.BitMask mask_$p = org.drools.model.BitMask.getPatternMask(DomainClassesMetadataF894883E1030542FEFCE9860F835B9B7.org_kie_kogito_queries_Person_Metadata_INSTANCE,
                                                                                         "adult");
        org.drools.model.Rule rule = D.rule("org.kie.kogito.queries",
                                            "CheckNotAdult").unit(org.kie.kogito.queries.AdultUnit.class)
                                                            .build(D.pattern(var_$p).expr("1ECF1D07CB65DA08A27F2E9295AE2940",
                                                                                          var_adultAge,
                                                                                          (_this, adultAge) -> org.drools.modelcompiler.util.EvaluationUtil.lessThanNumbers(_this.getAge(),
                                                                                                                                                                            adultAge),
                                                                                          D.betaIndexedBy(java.lang.Integer.class,
                                                                                                          org.drools.model.Index.ConstraintType.LESS_THAN,
                                                                                                          DomainClassesMetadataF894883E1030542FEFCE9860F835B9B7.org_kie_kogito_queries_Person_Metadata_INSTANCE.getPropertyIndex("age"),
                                                                                                          _this -> _this.getAge(),
                                                                                                          adultAge -> adultAge),
                                                                                          D.reactOn("age")),
                                                                   D.on(var_$p).execute((drools, $p) -> {
                                                                       {
                                                                           ($p).setAdult(false);
                                                                           drools.update($p,
                                                                                         mask_$p);
                                                                       }
                                                                   }));
        return rule;
    }
}
